@@ -93,9 +93,11 @@ class BastionPermissionSet(
         *,
         instance_arn: builtins.str,
         name: builtins.str,
+        customer_managed_policy_references: typing.Optional[typing.Union[aws_cdk.IResolvable, typing.Sequence[typing.Union[typing.Union[aws_cdk.aws_sso.CfnPermissionSet.CustomerManagedPolicyReferenceProperty, typing.Dict[str, typing.Any]], aws_cdk.IResolvable]]]] = None,
         description: typing.Optional[builtins.str] = None,
         inline_policy: typing.Any = None,
         managed_policies: typing.Optional[typing.Sequence[builtins.str]] = None,
+        permissions_boundary: typing.Optional[typing.Union[typing.Union[aws_cdk.aws_sso.CfnPermissionSet.PermissionsBoundaryProperty, typing.Dict[str, typing.Any]], aws_cdk.IResolvable]] = None,
         relay_state_type: typing.Optional[builtins.str] = None,
         session_duration: typing.Optional[builtins.str] = None,
         tags: typing.Optional[typing.Sequence[typing.Union[aws_cdk.CfnTag, typing.Dict[str, typing.Any]]]] = None,
@@ -106,9 +108,11 @@ class BastionPermissionSet(
         :param id: -
         :param instance_arn: The ARN of the SSO instance under which the operation will be executed. For more information about ARNs, see `Amazon Resource Names (ARNs) and AWS Service Namespaces <https://docs.aws.amazon.com//general/latest/gr/aws-arns-and-namespaces.html>`_ in the *AWS General Reference* .
         :param name: The name of the permission set.
+        :param customer_managed_policy_references: ``AWS::SSO::PermissionSet.CustomerManagedPolicyReferences``.
         :param description: The description of the ``PermissionSet`` .
         :param inline_policy: The IAM inline policy that is attached to the permission set.
         :param managed_policies: A structure that stores the details of the IAM managed policy.
+        :param permissions_boundary: ``AWS::SSO::PermissionSet.PermissionsBoundary``.
         :param relay_state_type: Used to redirect users within the application during the federation authentication process.
         :param session_duration: The length of time that the application user sessions are valid for in the ISO-8601 standard.
         :param tags: The tags to attach to the new ``PermissionSet`` .
@@ -123,9 +127,11 @@ class BastionPermissionSet(
         props = BastionPermissionSetProps(
             instance_arn=instance_arn,
             name=name,
+            customer_managed_policy_references=customer_managed_policy_references,
             description=description,
             inline_policy=inline_policy,
             managed_policies=managed_policies,
+            permissions_boundary=permissions_boundary,
             relay_state_type=relay_state_type,
             session_duration=session_duration,
             tags=tags,
@@ -865,9 +871,11 @@ class BastionInstanceProps(SecurityTagable):
     name_mapping={
         "instance_arn": "instanceArn",
         "name": "name",
+        "customer_managed_policy_references": "customerManagedPolicyReferences",
         "description": "description",
         "inline_policy": "inlinePolicy",
         "managed_policies": "managedPolicies",
+        "permissions_boundary": "permissionsBoundary",
         "relay_state_type": "relayStateType",
         "session_duration": "sessionDuration",
         "tags": "tags",
@@ -883,9 +891,11 @@ class BastionPermissionSetProps(
         *,
         instance_arn: builtins.str,
         name: builtins.str,
+        customer_managed_policy_references: typing.Optional[typing.Union[aws_cdk.IResolvable, typing.Sequence[typing.Union[typing.Union[aws_cdk.aws_sso.CfnPermissionSet.CustomerManagedPolicyReferenceProperty, typing.Dict[str, typing.Any]], aws_cdk.IResolvable]]]] = None,
         description: typing.Optional[builtins.str] = None,
         inline_policy: typing.Any = None,
         managed_policies: typing.Optional[typing.Sequence[builtins.str]] = None,
+        permissions_boundary: typing.Optional[typing.Union[typing.Union[aws_cdk.aws_sso.CfnPermissionSet.PermissionsBoundaryProperty, typing.Dict[str, typing.Any]], aws_cdk.IResolvable]] = None,
         relay_state_type: typing.Optional[builtins.str] = None,
         session_duration: typing.Optional[builtins.str] = None,
         tags: typing.Optional[typing.Sequence[typing.Union[aws_cdk.CfnTag, typing.Dict[str, typing.Any]]]] = None,
@@ -894,9 +904,11 @@ class BastionPermissionSetProps(
         '''
         :param instance_arn: The ARN of the SSO instance under which the operation will be executed. For more information about ARNs, see `Amazon Resource Names (ARNs) and AWS Service Namespaces <https://docs.aws.amazon.com//general/latest/gr/aws-arns-and-namespaces.html>`_ in the *AWS General Reference* .
         :param name: The name of the permission set.
+        :param customer_managed_policy_references: ``AWS::SSO::PermissionSet.CustomerManagedPolicyReferences``.
         :param description: The description of the ``PermissionSet`` .
         :param inline_policy: The IAM inline policy that is attached to the permission set.
         :param managed_policies: A structure that stores the details of the IAM managed policy.
+        :param permissions_boundary: ``AWS::SSO::PermissionSet.PermissionsBoundary``.
         :param relay_state_type: Used to redirect users within the application during the federation authentication process.
         :param session_duration: The length of time that the application user sessions are valid for in the ISO-8601 standard.
         :param tags: The tags to attach to the new ``PermissionSet`` .
@@ -908,9 +920,11 @@ class BastionPermissionSetProps(
             type_hints = typing.get_type_hints(BastionPermissionSetProps.__init__)
             check_type(argname="argument instance_arn", value=instance_arn, expected_type=type_hints["instance_arn"])
             check_type(argname="argument name", value=name, expected_type=type_hints["name"])
+            check_type(argname="argument customer_managed_policy_references", value=customer_managed_policy_references, expected_type=type_hints["customer_managed_policy_references"])
             check_type(argname="argument description", value=description, expected_type=type_hints["description"])
             check_type(argname="argument inline_policy", value=inline_policy, expected_type=type_hints["inline_policy"])
             check_type(argname="argument managed_policies", value=managed_policies, expected_type=type_hints["managed_policies"])
+            check_type(argname="argument permissions_boundary", value=permissions_boundary, expected_type=type_hints["permissions_boundary"])
             check_type(argname="argument relay_state_type", value=relay_state_type, expected_type=type_hints["relay_state_type"])
             check_type(argname="argument session_duration", value=session_duration, expected_type=type_hints["session_duration"])
             check_type(argname="argument tags", value=tags, expected_type=type_hints["tags"])
@@ -919,12 +933,16 @@ class BastionPermissionSetProps(
             "instance_arn": instance_arn,
             "name": name,
         }
+        if customer_managed_policy_references is not None:
+            self._values["customer_managed_policy_references"] = customer_managed_policy_references
         if description is not None:
             self._values["description"] = description
         if inline_policy is not None:
             self._values["inline_policy"] = inline_policy
         if managed_policies is not None:
             self._values["managed_policies"] = managed_policies
+        if permissions_boundary is not None:
+            self._values["permissions_boundary"] = permissions_boundary
         if relay_state_type is not None:
             self._values["relay_state_type"] = relay_state_type
         if session_duration is not None:
@@ -956,6 +974,17 @@ class BastionPermissionSetProps(
         assert result is not None, "Required property 'name' is missing"
         return typing.cast(builtins.str, result)
 
+    @builtins.property
+    def customer_managed_policy_references(
+        self,
+    ) -> typing.Optional[typing.Union[aws_cdk.IResolvable, typing.List[typing.Union[aws_cdk.aws_sso.CfnPermissionSet.CustomerManagedPolicyReferenceProperty, aws_cdk.IResolvable]]]]:
+        '''``AWS::SSO::PermissionSet.CustomerManagedPolicyReferences``.
+
+        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-sso-permissionset.html#cfn-sso-permissionset-customermanagedpolicyreferences
+        '''
+        result = self._values.get("customer_managed_policy_references")
+        return typing.cast(typing.Optional[typing.Union[aws_cdk.IResolvable, typing.List[typing.Union[aws_cdk.aws_sso.CfnPermissionSet.CustomerManagedPolicyReferenceProperty, aws_cdk.IResolvable]]]], result)
+
     @builtins.property
     def description(self) -> typing.Optional[builtins.str]:
         '''The description of the ``PermissionSet`` .
@@ -983,6 +1012,17 @@ class BastionPermissionSetProps(
         result = self._values.get("managed_policies")
         return typing.cast(typing.Optional[typing.List[builtins.str]], result)
 
+    @builtins.property
+    def permissions_boundary(
+        self,
+    ) -> typing.Optional[typing.Union[aws_cdk.aws_sso.CfnPermissionSet.PermissionsBoundaryProperty, aws_cdk.IResolvable]]:
+        '''``AWS::SSO::PermissionSet.PermissionsBoundary``.
+
+        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-sso-permissionset.html#cfn-sso-permissionset-permissionsboundary
+        '''
+        result = self._values.get("permissions_boundary")
+        return typing.cast(typing.Optional[typing.Union[aws_cdk.aws_sso.CfnPermissionSet.PermissionsBoundaryProperty, aws_cdk.IResolvable]], result)
+
     @builtins.property
     def relay_state_type(self) -> typing.Optional[builtins.str]:
         '''Used to redirect users within the application during the federation authentication process.
