@@ -50,6 +50,8 @@ class StaticSite(
         *,
         domain: builtins.str,
         path: builtins.str,
+        alternative_domains: typing.Optional[typing.Sequence[builtins.str]] = None,
+        alternative_hosted_zones: typing.Optional[typing.Sequence[aws_cdk.aws_route53.IHostedZone]] = None,
         hosted_zone: typing.Optional[aws_cdk.aws_route53.IHostedZone] = None,
     ) -> None:
         '''
@@ -57,6 +59,8 @@ class StaticSite(
         :param id: -
         :param domain: 
         :param path: 
+        :param alternative_domains: 
+        :param alternative_hosted_zones: 
         :param hosted_zone: 
 
         :stability: experimental
@@ -65,7 +69,13 @@ class StaticSite(
             type_hints = typing.get_type_hints(StaticSite.__init__)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
-        props = StaticSiteProps(domain=domain, path=path, hosted_zone=hosted_zone)
+        props = StaticSiteProps(
+            domain=domain,
+            path=path,
+            alternative_domains=alternative_domains,
+            alternative_hosted_zones=alternative_hosted_zones,
+            hosted_zone=hosted_zone,
+        )
 
         jsii.create(self.__class__, self, [scope, id, props])
 
@@ -88,7 +98,13 @@ class StaticSite(
 @jsii.data_type(
     jsii_type="pwed-cdk.static_site.StaticSiteProps",
     jsii_struct_bases=[],
-    name_mapping={"domain": "domain", "path": "path", "hosted_zone": "hostedZone"},
+    name_mapping={
+        "domain": "domain",
+        "path": "path",
+        "alternative_domains": "alternativeDomains",
+        "alternative_hosted_zones": "alternativeHostedZones",
+        "hosted_zone": "hostedZone",
+    },
 )
 class StaticSiteProps:
     def __init__(
@@ -96,11 +112,15 @@ class StaticSiteProps:
         *,
         domain: builtins.str,
         path: builtins.str,
+        alternative_domains: typing.Optional[typing.Sequence[builtins.str]] = None,
+        alternative_hosted_zones: typing.Optional[typing.Sequence[aws_cdk.aws_route53.IHostedZone]] = None,
         hosted_zone: typing.Optional[aws_cdk.aws_route53.IHostedZone] = None,
     ) -> None:
         '''
         :param domain: 
         :param path: 
+        :param alternative_domains: 
+        :param alternative_hosted_zones: 
         :param hosted_zone: 
 
         :stability: experimental
@@ -109,11 +129,17 @@ class StaticSiteProps:
             type_hints = typing.get_type_hints(StaticSiteProps.__init__)
             check_type(argname="argument domain", value=domain, expected_type=type_hints["domain"])
             check_type(argname="argument path", value=path, expected_type=type_hints["path"])
+            check_type(argname="argument alternative_domains", value=alternative_domains, expected_type=type_hints["alternative_domains"])
+            check_type(argname="argument alternative_hosted_zones", value=alternative_hosted_zones, expected_type=type_hints["alternative_hosted_zones"])
             check_type(argname="argument hosted_zone", value=hosted_zone, expected_type=type_hints["hosted_zone"])
         self._values: typing.Dict[str, typing.Any] = {
             "domain": domain,
             "path": path,
         }
+        if alternative_domains is not None:
+            self._values["alternative_domains"] = alternative_domains
+        if alternative_hosted_zones is not None:
+            self._values["alternative_hosted_zones"] = alternative_hosted_zones
         if hosted_zone is not None:
             self._values["hosted_zone"] = hosted_zone
 
@@ -135,6 +161,24 @@ class StaticSiteProps:
         assert result is not None, "Required property 'path' is missing"
         return typing.cast(builtins.str, result)
 
+    @builtins.property
+    def alternative_domains(self) -> typing.Optional[typing.List[builtins.str]]:
+        '''
+        :stability: experimental
+        '''
+        result = self._values.get("alternative_domains")
+        return typing.cast(typing.Optional[typing.List[builtins.str]], result)
+
+    @builtins.property
+    def alternative_hosted_zones(
+        self,
+    ) -> typing.Optional[typing.List[aws_cdk.aws_route53.IHostedZone]]:
+        '''
+        :stability: experimental
+        '''
+        result = self._values.get("alternative_hosted_zones")
+        return typing.cast(typing.Optional[typing.List[aws_cdk.aws_route53.IHostedZone]], result)
+
     @builtins.property
     def hosted_zone(self) -> typing.Optional[aws_cdk.aws_route53.IHostedZone]:
         '''
